==> zio-aws-computeoptimizer_3-5.17.116.1-sources.jar: zio/aws/computeoptimizer/model/GetEnrollmentStatusesForOrganizationRequest.scala <==
package zio.aws.computeoptimizer.model
import java.lang.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.computeoptimizer.model.primitives.{MaxResults, NextToken}
import scala.jdk.CollectionConverters.*
final case class GetEnrollmentStatusesForOrganizationRequest(
    filters: Option[Iterable[zio.aws.computeoptimizer.model.EnrollmentFilter]] =
      None,
    nextToken: Option[NextToken] = None,
    maxResults: Option[MaxResults] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.computeoptimizer.model.GetEnrollmentStatusesForOrganizationRequest = {
    import GetEnrollmentStatusesForOrganizationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.computeoptimizer.model.GetEnrollmentStatusesForOrganizationRequest
      .builder()
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        maxResults.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .build()
  }
  def asReadOnly
      : zio.aws.computeoptimizer.model.GetEnrollmentStatusesForOrganizationRequest.ReadOnly =
    zio.aws.computeoptimizer.model.GetEnrollmentStatusesForOrganizationRequest
      .wrap(buildAwsValue())
}
object GetEnrollmentStatusesForOrganizationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.computeoptimizer.model.GetEnrollmentStatusesForOrganizationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.computeoptimizer.model.GetEnrollmentStatusesForOrganizationRequest =
      zio.aws.computeoptimizer.model
        .GetEnrollmentStatusesForOrganizationRequest(
          filters.map(value =>
            value.map { item =>
              item.asEditable
            }
          ),
          nextToken.map(value => value),
          maxResults.map(value => value)
        )
    def filters
        : Option[List[zio.aws.computeoptimizer.model.EnrollmentFilter.ReadOnly]]
    def nextToken: Option[NextToken]
    def maxResults: Option[MaxResults]
    def getFilters: ZIO[Any, AwsError, List[
      zio.aws.computeoptimizer.model.EnrollmentFilter.ReadOnly
    ]] = AwsError.unwrapOptionField("filters", filters)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getMaxResults: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.computeoptimizer.model.GetEnrollmentStatusesForOrganizationRequest
  ) extends zio.aws.computeoptimizer.model.GetEnrollmentStatusesForOrganizationRequest.ReadOnly {
    override val filters: Option[
      List[zio.aws.computeoptimizer.model.EnrollmentFilter.ReadOnly]
    ] = scala
      .Option(impl.filters())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.computeoptimizer.model.EnrollmentFilter.wrap(item)
        }.toList
      )
    override val nextToken: Option[NextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.computeoptimizer.model.primitives.NextToken(value))
    override val maxResults: Option[MaxResults] = scala
      .Option(impl.maxResults())
      .map(value => zio.aws.computeoptimizer.model.primitives.MaxResults(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.computeoptimizer.model.GetEnrollmentStatusesForOrganizationRequest
  ): zio.aws.computeoptimizer.model.GetEnrollmentStatusesForOrganizationRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-computeoptimizer_3-5.17.225.2-sources.jar: zio/aws/computeoptimizer/model/GetEnrollmentStatusesForOrganizationRequest.scala <==
package zio.aws.computeoptimizer.model
import zio.aws.computeoptimizer.model.primitives.{MaxResults, NextToken}
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class GetEnrollmentStatusesForOrganizationRequest(
    filters: Optional[
      Iterable[zio.aws.computeoptimizer.model.EnrollmentFilter]
    ] = Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent,
    maxResults: Optional[MaxResults] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.computeoptimizer.model.GetEnrollmentStatusesForOrganizationRequest = {
    import GetEnrollmentStatusesForOrganizationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.computeoptimizer.model.GetEnrollmentStatusesForOrganizationRequest
      .builder()
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        maxResults.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .build()
  }
  def asReadOnly
      : zio.aws.computeoptimizer.model.GetEnrollmentStatusesForOrganizationRequest.ReadOnly =
    zio.aws.computeoptimizer.model.GetEnrollmentStatusesForOrganizationRequest
      .wrap(buildAwsValue())
}
object GetEnrollmentStatusesForOrganizationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.computeoptimizer.model.GetEnrollmentStatusesForOrganizationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.computeoptimizer.model.GetEnrollmentStatusesForOrganizationRequest =
      zio.aws.computeoptimizer.model
        .GetEnrollmentStatusesForOrganizationRequest(
          filters.map(value =>
            value.map { item =>
              item.asEditable
            }
          ),
          nextToken.map(value => value),
          maxResults.map(value => value)
        )
    def filters: Optional[
      List[zio.aws.computeoptimizer.model.EnrollmentFilter.ReadOnly]
    ]
    def nextToken: Optional[NextToken]
    def maxResults: Optional[MaxResults]
    def getFilters: ZIO[Any, AwsError, List[
      zio.aws.computeoptimizer.model.EnrollmentFilter.ReadOnly
    ]] = AwsError.unwrapOptionField("filters", filters)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getMaxResults: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.computeoptimizer.model.GetEnrollmentStatusesForOrganizationRequest
  ) extends zio.aws.computeoptimizer.model.GetEnrollmentStatusesForOrganizationRequest.ReadOnly {
    override val filters: Optional[
      List[zio.aws.computeoptimizer.model.EnrollmentFilter.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.filters())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.computeoptimizer.model.EnrollmentFilter.wrap(item)
        }.toList
      )
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.computeoptimizer.model.primitives.NextToken(value))
    override val maxResults: Optional[MaxResults] = zio.aws.core.internal
      .optionalFromNullable(impl.maxResults())
      .map(value => zio.aws.computeoptimizer.model.primitives.MaxResults(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.computeoptimizer.model.GetEnrollmentStatusesForOrganizationRequest
  ): zio.aws.computeoptimizer.model.GetEnrollmentStatusesForOrganizationRequest.ReadOnly =
    new Wrapper(impl)
}
